define(
//begin v1.x content
({
	insertTableTitle: "Sett inn tabell",
	modifyTableTitle: "Endre tabell",
	rows: "Rader:",
	columns: "Kolonner:",
	align: "Juster:",
	cellPadding: "Celleutfylling:",
	cellSpacing: "Celleavstand:",
	tableWidth: "Tabellbredde:",
	backgroundColor: "Bakgrunnsfarge:",
	borderColor: "Kantlinjefarge:",
	borderThickness: "Kanttykkelse",
	percent: "prosent",
	pixels: "piksler",
	"default": "standard",
	left: "venstre",
	center: "midtstill",
	right: "høyre",
	buttonSet: "Definer", // translated elsewhere?
	buttonInsert: "Sett inn",
	buttonCancel: "Avbryt",

	selectTableLabel: "Velg tabell",
	insertTableRowBeforeLabel: "Legg til rad foran",
	insertTableRowAfterLabel: "Legg til rad etter",
	insertTableColumnBeforeLabel: "Legg til kolonne foran",
	insertTableColumnAfterLabel: "Legg til kolonne etter",
	deleteTableRowLabel: "Slett rad",
	deleteTableColumnLabel: "Slett kolonne"
})
//end v1.x content
);
